# tba

[![PyPI version](https://badge.fury.io/py/tba.svg)](https://badge.fury.io/py/tba)  [![codecov](https://codecov.io/gh/doerlbh/tba/branch/main/graph/badge.svg?token=)](https://codecov.io/gh/doerlbh/tba) [![Travis_CI](https://travis-ci.com/doerlbh/tba.svg?token=&branch=main)](https://travis-ci.com/doerlbh/tba) [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

Python library

Created by [Baihan Lin](www.baihan.nyc), Columbia University
